// 导入动画和视差效果库
import AOS from 'aos';
import 'aos/dist/aos.css';
import Parallax from 'parallax-js';

// 初始化AOS动画库
export function initAOS() {
  AOS.init({
    duration: 800,     // 动画持续时间
    easing: 'ease',    // 动画曲线
    once: true,        // 动画是否只播放一次
    offset: 120,       // 触发偏移量
    delay: 0,          // 延迟时间
    anchorPlacement: 'top-bottom', // 锚点位置
  });
}

// 初始化Parallax.js视差效果
export function initParallax() {
  // 获取所有带有parallax-container类的元素
  const scenes = document.querySelectorAll('.parallax-container');
  
  // 为每个元素创建视差实例
  scenes.forEach(scene => {
    new Parallax(scene, {
      relativeInput: true,
      clipRelativeInput: true,
      hoverOnly: false,
      inputElement: document.documentElement
    });
  });
}

// 导出一个函数用于在Vue应用中初始化所有动画效果
export default function initAnimations() {
  // 在DOM加载完成后初始化
  window.addEventListener('DOMContentLoaded', () => {
    initAOS();
    initParallax();
  });
  
  // 在窗口大小改变时刷新AOS
  window.addEventListener('resize', () => {
    AOS.refresh();
  });
}